==> ktp-text-ui-16.12.3.tar.xz: ktp-text-ui-16.12.3/filters/formatting/ktptextui_message_filter_formatting.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Text Formatting
Name[ar]=تنسيق النّصّ
Name[ast]=Formatéu del testu
Name[bs]=Formatiranje teksta
Name[ca]=Formatació del text
Name[ca@valencia]=Formatació del text
Name[cs]=Formátování textu
Name[da]=Tekstformatering
Name[de]=Textformatierung
Name[el]=Διαμόρφωση κειμένου
Name[en_GB]=Text Formatting
Name[es]=Formateo de texto
Name[et]=Teksti vormindamine
Name[fi]=Tekstin muotoilu
Name[fr]=Formatage du texte
Name[gl]=Formato do texto
Name[hu]=Szövegformázás
Name[ia]=Dar forma a texto
Name[it]=Formattazione del testo
Name[kk]=Пішімделген мәтін
Name[ko]=텍스트 서식
Name[lt]=Teksto formatavimas
Name[mr]=मजकूर फॉर्मेटिंग
Name[nb]=Tekstformatering
Name[nds]=Textformateren
Name[nl]=Tekstopmaak
Name[nn]=Tekstformatering
Name[pa]=ਟੈਕਸਟ ਫਾਰਮੈਟ
Name[pl]=Formatowanie tekstu
Name[pt]=Formatação do Texto
Name[pt_BR]=Formatação de texto
Name[ro]=Formatarea textului
Name[ru]=Форматирование текста
Name[sk]=Formátovanie textu
Name[sl]=Oblikovanje besedila
Name[sr]=Форматирање текста
Name[sr@ijekavian]=Форматирање текста
Name[sr@ijekavianlatin]=Formatiranje teksta
Name[sr@latin]=Formatiranje teksta
Name[sv]=Textformatering
Name[tr]=Metin Biçimlendirme
Name[ug]=تېكىست فورماتى
Name[uk]=Форматування тексту
Name[x-test]=xxText Formattingxx
Name[zh_CN]=文本格式化
Name[zh_TW]=文字格式
Comment=Use /, _, * and - to make text italic, underlined, bold or strikeout respectively
Comment[bs]=Koristite _, * i - da napravite tekst kurzivnim, podebljanim ili precrtanim
Comment[ca]=Usa /, _, * i - per a convertir el text a cursiva, subratllat, negreta o ratllat respectivament
Comment[ca@valencia]=Usa /, _, * i - per a convertir el text a cursiva, subratllat, negreta o ratllat respectivament
Comment[cs]=Použít /,_, * a - pro kurzívu, podtržený, tučný a přeškrtnutý text
Comment[da]=Brug /, _, * og - til at lave hhv. kursiv, fed eller overstreget
Comment[de]=Mit „/“, „_“, “*“ und „-“ wird Text geneigt, unterstrichen, fett oder durchgestrichen dargestellt
Comment[el]=Χρησιμοποιήστε /, _, * και - για πλάγιους, υπογραμμισμένους, έντονους ή με επιγράμμιση χαρακτήρες αντίστοιχα
Comment[en_GB]=Use /, _, * and - to make text italic, underlined, bold or strikeout respectively
Comment[es]=Utilice /, _, * y - para poner el texto en cursiva, subrayado, negrita o tachado respectivamente
Comment[et]= /, _, * ja - kasutamine teksti muutmiseks kaldkirja, allajoonituks, rasvaseks või läbikriipsutatuks
Comment[fi]=Käytä merkkejä /, _, * ja - tekstin kursivointiin, alleviivaamiseen, lihavoittamiseen tai yliviivaamiseen
Comment[fr]=Utilise « / », « _ », « * » et « - » pour créer du texte, respectivement, en italique, en gras ou en barré
Comment[gl]=Use /, _, * e - para pór o texto en cursiva, subraiado, negra e riscado, respectivamente
Comment[hu]=A /, _, * és - használatával teheti a szöveget döntötté, aláhúzottá, félkövérré vagy áthúzottá
Comment[ia]=Usa /,_,* e - pro facer texto cursive, sublineate, grasse o strikeout respectivemente
Comment[it]=Usa /, _, * e - per rendere il testo rispettivamente corsivo, sottolineato, grassetto o barrato
Comment[kk]=Мәтінді көлбеу, асты сызық, қалың, сызып тастаған қылу үшін  /, _, * және - пайдалану
Comment[ko]=/, _, *, - 기호를 사용하여 기울임꼴, 밑줄, 굵게, 취소선 효과 사용하기
Comment[lt]=Naudokite /, _, * ir - kad parašyti tekstą pasvirai, pabrauktą, paryškintą ar perbrauktą
Comment[nb]=Bruk /, _,* og – for å gjøre teksten henholdsvis kursiv, understreket, halvfet eller overstreket
Comment[nds]=»/«, »_«, »*« un »-« bruken un Text dor mit kursiev, ünnerstreken, fett oder dörstreken wiesen
Comment[nl]=Gebruik /, _, * en - om tekst respectievelijk cursief, onderstreept, vet of doorgestreept te maken
Comment[nn]=Bruk «/», «_», «*» og «-» for markera kursiv, understreking, halvfeit og gjennomstreking
Comment[pl]=Użyj odpowiednio /,_, * i - aby tekst był napisany kursywą, podkreślony, pogrubiony lub przekreślony
Comment[pt]=Usar o '/', '_', '*' e '-' para tornar o texto itálico, sublinhado, negrito ou traçado, respectivamente
Comment[pt_BR]=Use /, _, * e - para tornar o texto itálico, sublinhado, negrito ou tachado, respectivamente
Comment[ro]=Folosiți /, _, * și - pentru a face textul cursiv, subliniat, aldin sau tăiat, respectiv
Comment[ru]=Использовать «/» для обозначения курсива, «*» для полужирного, «_» для подчёркнутого и «-» для зачёркнутого текста
Comment[sk]=Použite /,  _, * a - na zmenu textu na kurzívu, podčiarknuté, tučné alebo prečiarknuté
Comment[sl]=Uporabite /,_, * in -, da bo besedilo ležeče, podčrtano, krepko ali prečrtano
Comment[sr]=/, _, * и - за курзив, подвучено, подебљано и прецртано
Comment[sr@ijekavian]=/, _, * и - за курзив, подвучено, подебљано и прецртано
Comment[sr@ijekavianlatin]=/, _, * i - za kurziv, podvučeno, podebljano i precrtano
Comment[sr@latin]=/, _, * i - za kurziv, podvučeno, podebljano i precrtano
Comment[sv]=Använd /, _, * och - för att antingen visa texten kursiv, understruken, med fetstil eller överstruken
Comment[tr]=Metni eğik, kalın veya üzeri çizili yapmak için sırasıyla /, _, * ve - kullanın
Comment[uk]=Використовувати /, _, * і - для курсиву, підкресленого, напівжирного та перекресленого тексту, відповідно
Comment[x-test]=xxUse /, _, * and - to make text italic, underlined, bold or strikeout respectivelyxx
Comment[zh_CN]=使用 /、_、* 和 - 来使文本变为下划线、斜体、粗体或删除线
Comment[zh_TW]=用 /, _, * 與 - 來顯示文字的斜體、底線、粗體與刪除線。
Type=Service
ServiceTypes=KTpTextUi/MessageFilter
X-KDE-Library=ktptextui_message_filter_formatting
X-KDE-PluginInfo-Author=KDE Telepathy Developers
X-KDE-PluginInfo-Email=kde-telepathy@kde.org
X-KDE-PluginInfo-Name=formatting
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

==> ktp-text-ui-17.03.80.tar.xz: ktp-text-ui-17.03.80/filters/formatting/ktptextui_message_filter_formatting.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Text Formatting
Name[ar]=تنسيق النّصّ
Name[ast]=Formatéu de testu
Name[bs]=Formatiranje teksta
Name[ca]=Formatació del text
Name[ca@valencia]=Formatació del text
Name[cs]=Formátování textu
Name[da]=Tekstformatering
Name[de]=Textformatierung
Name[el]=Διαμόρφωση κειμένου
Name[en_GB]=Text Formatting
Name[es]=Formateo de texto
Name[et]=Teksti vormindamine
Name[fi]=Tekstin muotoilu
Name[fr]=Formatage du texte
Name[gl]=Formato do texto
Name[hu]=Szövegformázás
Name[ia]=Dar forma a texto
Name[it]=Formattazione del testo
Name[kk]=Пішімделген мәтін
Name[ko]=텍스트 서식
Name[lt]=Teksto formatavimas
Name[mr]=मजकूर फॉर्मेटिंग
Name[nb]=Tekstformatering
Name[nds]=Textformateren
Name[nl]=Tekstopmaak
Name[nn]=Tekstformatering
Name[pa]=ਟੈਕਸਟ ਫਾਰਮੈਟ
Name[pl]=Formatowanie tekstu
Name[pt]=Formatação do Texto
Name[pt_BR]=Formatação de texto
Name[ro]=Formatarea textului
Name[ru]=Форматирование текста
Name[sk]=Formátovanie textu
Name[sl]=Oblikovanje besedila
Name[sr]=Форматирање текста
Name[sr@ijekavian]=Форматирање текста
Name[sr@ijekavianlatin]=Formatiranje teksta
Name[sr@latin]=Formatiranje teksta
Name[sv]=Textformatering
Name[tr]=Metin Biçimlendirme
Name[ug]=تېكىست فورماتى
Name[uk]=Форматування тексту
Name[x-test]=xxText Formattingxx
Name[zh_CN]=文本格式化
Name[zh_TW]=文字格式
Comment=Use /, _, * and - to make text italic, underlined, bold or strikeout respectively
Comment[ast]=Usa /, _, * y - pa poner el testu en cursiva, sorrayáu, negrina o tacháu respeutivamente
Comment[bs]=Koristite _, * i - da napravite tekst kurzivnim, podebljanim ili precrtanim
Comment[ca]=Usa /, _, * i - per a convertir el text a cursiva, subratllat, negreta o ratllat respectivament
Comment[ca@valencia]=Usa /, _, * i - per a convertir el text a cursiva, subratllat, negreta o ratllat respectivament
Comment[cs]=Použít /,_, * a - pro kurzívu, podtržený, tučný a přeškrtnutý text
Comment[da]=Brug /, _, * og - til at lave hhv. kursiv, fed eller overstreget
Comment[de]=Mit „/“, „_“, “*“ und „-“ wird Text geneigt, unterstrichen, fett oder durchgestrichen dargestellt
Comment[el]=Χρησιμοποιήστε /, _, * και - για πλάγιους, υπογραμμισμένους, έντονους ή με επιγράμμιση χαρακτήρες αντίστοιχα
Comment[en_GB]=Use /, _, * and - to make text italic, underlined, bold or strikeout respectively
Comment[es]=Utilice /, _, * y - para poner el texto en cursiva, subrayado, negrita o tachado respectivamente
Comment[et]= /, _, * ja - kasutamine teksti muutmiseks kaldkirja, allajoonituks, rasvaseks või läbikriipsutatuks
Comment[fi]=Käytä merkkejä /, _, * ja - tekstin kursivointiin, alleviivaamiseen, lihavoittamiseen tai yliviivaamiseen
Comment[fr]=Utilise « / », « _ », « * » et « - » pour créer du texte, respectivement, en italique, en gras ou en barré
Comment[gl]=Use /, _, * e - para pór o texto en cursiva, subraiado, negra e riscado, respectivamente
Comment[hu]=A /, _, * és - használatával teheti a szöveget döntötté, aláhúzottá, félkövérré vagy áthúzottá
Comment[ia]=Usa /,_,* e - pro facer texto cursive, sublineate, grasse o strikeout respectivemente
Comment[it]=Usa /, _, * e - per rendere il testo rispettivamente corsivo, sottolineato, grassetto o barrato
Comment[kk]=Мәтінді көлбеу, асты сызық, қалың, сызып тастаған қылу үшін  /, _, * және - пайдалану
Comment[ko]=/, _, *, - 기호를 사용하여 기울임꼴, 밑줄, 굵게, 취소선 효과 사용하기
Comment[lt]=Naudokite /, _, * ir - kad parašyti tekstą pasvirai, pabrauktą, paryškintą ar perbrauktą
Comment[nb]=Bruk /, _,* og – for å gjøre teksten henholdsvis kursiv, understreket, halvfet eller overstreket
Comment[nds]=»/«, »_«, »*« un »-« bruken un Text dor mit kursiev, ünnerstreken, fett oder dörstreken wiesen
Comment[nl]=Gebruik /, _, * en - om tekst respectievelijk cursief, onderstreept, vet of doorgestreept te maken
Comment[nn]=Bruk «/», «_», «*» og «-» for markera kursiv, understreking, halvfeit og gjennomstreking
Comment[pl]=Użyj odpowiednio /,_, * i - aby tekst był napisany kursywą, podkreślony, pogrubiony lub przekreślony
Comment[pt]=Usar o '/', '_', '*' e '-' para tornar o texto itálico, sublinhado, negrito ou traçado, respectivamente
Comment[pt_BR]=Use /, _, * e - para tornar o texto itálico, sublinhado, negrito ou tachado, respectivamente
Comment[ro]=Folosiți /, _, * și - pentru a face textul cursiv, subliniat, aldin sau tăiat, respectiv
Comment[ru]=Использовать «/» для обозначения курсива, «*» для полужирного, «_» для подчёркнутого и «-» для зачёркнутого текста
Comment[sk]=Použite /,  _, * a - na zmenu textu na kurzívu, podčiarknuté, tučné alebo prečiarknuté
Comment[sl]=Uporabite /,_, * in -, da bo besedilo ležeče, podčrtano, krepko ali prečrtano
Comment[sr]=/, _, * и - за курзив, подвучено, подебљано и прецртано
Comment[sr@ijekavian]=/, _, * и - за курзив, подвучено, подебљано и прецртано
Comment[sr@ijekavianlatin]=/, _, * i - za kurziv, podvučeno, podebljano i precrtano
Comment[sr@latin]=/, _, * i - za kurziv, podvučeno, podebljano i precrtano
Comment[sv]=Använd /, _, * och - för att antingen visa texten kursiv, understruken, med fetstil eller överstruken
Comment[tr]=Metni eğik, kalın veya üzeri çizili yapmak için sırasıyla /, _, * ve - kullanın
Comment[uk]=Використовувати /, _, * і - для курсиву, підкресленого, напівжирного та перекресленого тексту, відповідно
Comment[x-test]=xxUse /, _, * and - to make text italic, underlined, bold or strikeout respectivelyxx
Comment[zh_CN]=使用 /、_、* 和 - 来使文本变为下划线、斜体、粗体或删除线
Comment[zh_TW]=用 /, _, * 與 - 來顯示文字的斜體、底線、粗體與刪除線。
Type=Service
ServiceTypes=KTpTextUi/MessageFilter
X-KDE-Library=ktptextui_message_filter_formatting
X-KDE-PluginInfo-Author=KDE Telepathy Developers
X-KDE-PluginInfo-Email=kde-telepathy@kde.org
X-KDE-PluginInfo-Name=formatting
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@
